"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const nock = require("nock");
const index_1 = require("../src/index");
describe('Lang', () => {
    it('should set clientId and accessToken', () => {
        const lang = new index_1.default({
            token: 'token1234',
        });
        expect(lang.config.token).toEqual('token1234');
    });
});
describe('Request', () => {
    const endpoint = 'analyze';
    const projectId = '123';
    const text = 'abc';
    const token = 'token';
    const params = { text, projectId };
    const lang = new index_1.default({ token: '123' });
    it('should return a missing token error', () => __awaiter(this, void 0, void 0, function* () {
        const langNoToken = new index_1.default({ token: '' });
        try {
            yield langNoToken.analyze({});
        }
        catch (err) {
            expect(err).toMatchSnapshot();
        }
    }));
    it('should return a missing projectId error', () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield lang.analyze({});
        }
        catch (err) {
            expect(err).toMatchSnapshot();
        }
    }));
    it('should return a missing text error', () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield lang.analyze({ projectId });
        }
        catch (err) {
            expect(err).toMatchSnapshot();
        }
    }));
    it('should return a status error', done => {
        nock('https://api.lang.ai')
            .post(`/v1/${endpoint}`)
            .reply(400, { message: 'error' });
        lang.analyze(params).catch(err => {
            expect(err).toMatchSnapshot();
            done();
        });
    });
    it('should return an unexpected error', done => {
        nock('https://api.lang.ai')
            .post(`/v1/${endpoint}`)
            .replyWithError('something awful happened');
        lang.analyze(params).catch(err => {
            expect(err).toMatchSnapshot();
            done();
        });
    });
    it('should return a value', done => {
        nock('https://api.lang.ai')
            .post(`/v1/${endpoint}`)
            .reply(200, {
            intents: [{ name: 'collection+await', features: [] }],
        });
        lang.analyze(params).then(data => {
            expect(data).toMatchSnapshot();
            done();
        });
    });
});
