"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const needle = require("needle");
class Lang {
    /**
     * Create a new instance of lang class
     * @param config
     * @param config.token
     */
    constructor(config) {
        const apiVersion = config.apiVersion || 'v1';
        this.baseApiUrl = 'https://api.lang.ai';
        this.apiUrl = `${this.baseApiUrl}/${apiVersion}/`;
        this.config = {
            token: config.token,
        };
    }
    analyze(params) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.config.token) {
                throw new Error('Token is missing');
            }
            if (!params.projectId) {
                throw new Error('Parameter "projectId" is missing');
            }
            if (!params.text) {
                throw new Error('Parameter "text" is missing');
            }
            const method = 'analyze';
            const options = {
                headers: {
                    Authorization: `Bearer ${this.config.token}`,
                },
                json: true,
            };
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                const endpoint = this.apiUrl + method;
                needle('post', endpoint, params, options)
                    .then(res => {
                    if (res.statusCode !== 200) {
                        return reject(new Error(`Status ${res.statusCode}`));
                    }
                    resolve(res.body);
                })
                    .catch(err => {
                    if (err) {
                        return reject(err);
                    }
                });
            }));
        });
    }
}
exports.default = Lang;
